==> larus_board-0.8.36.tbz: larus_board-0.8.36/lb_private/lang/en/register.php <==
<?php
/* LARUS BOARD ========================================================
 * Encoded in UTF-8 (micro symbol: µ)
 * Copyright © 2008 by "The Larus Board Team"
 * This file is part of "Larus Board" and is licensed under
 * Creative Commons Attribution-Share Alike 3.0
 *
 * You should have received a copy of the license
 * along with this package. If not, see
 * <http://download.savannah.gnu.org/releases/larusboard/COPYING.CC>.
 */
$lang = array(
'register_account'=>'Register an user account',
'terms_of_use'=>'Our terms of use',
'explain_username'=>'You have to choose an username for your account. It must be at least three characters long and must not
exceed thirtytwo (32) characters. Any letters, digits or special chars are allowed, except the name is numeric only.',
'explain_mail'=>'You have to provide a valid e-mail address here. After registration you will receive a mail here including your
password and further instructions using your shiny new account.',
'invalid_username'=>'Your provided username is invalid!',
'invalid_mail'=>'You have set an invalid e-mail address!',
'username_already_used'=>'This username is already used. Please use another!',
'account_successfully_registered'=>'Your user account has been registered and the mail is sent.',
'account_activation_success'=>'Your user account has been activated. You may now login.',
'already_activated'=>'This account is already activated and ready for use!',
'time_limit_exceeded'=>'Your time limit for activation has exceeded!',
'hash_not_equal'=>'The activation string is not correct!',
'decline'=>'Decline'
);
?>

==> larus_board-0.9.0.tbz: larus_board-0.9.0/lb_private/lang/en/register.php <==
<?php
/* LARUS BOARD ========================================================
 * Encoded in UTF-8 (micro symbol: µ)
 * Copyright © 2008 by "The Larus Board Team"
 * This file is part of "Larus Board" and is licensed under
 * Creative Commons Attribution-Share Alike 3.0
 *
 * You should have received a copy of the license
 * along with this package. If not, see
 * <http://download.savannah.gnu.org/releases/larusboard/COPYING.CC>.
 */
$lang = array(
'register_account'=>'Register an user account',
'terms_of_use'=>'Our terms of use',
'explain_username'=>'You have to choose an username for your account. It must be at least three characters long and must not
exceed thirtytwo (32) characters. Any letters, digits or special chars are allowed, except the name is numeric only.',
'explain_mail'=>'You have to provide a valid e-mail address here. After registration you will receive a mail including your
password and further instructions. It is possible to use a disposable address as you can use your account without any e-mail
address after verification, although not recommended.',
'invalid_username'=>'Your provided username is invalid!',
'invalid_mail'=>'You have set an invalid e-mail address!',
'username_already_used'=>'This username is already used. Please use another!',
'account_successfully_registered'=>'Your user account has been registered and the mail is sent.',
'account_activation_success'=>'Your user account has been activated. You may now login.',
'already_activated'=>'This account is already activated and ready for use!',
'time_limit_exceeded'=>'Your time limit for activation has exceeded!',
'hash_not_equal'=>'The activation string is not correct!',
'decline'=>'Decline'
);
?>
